summaryrefslogtreecommitdiffstats
path: root/kjumpingcube/kcubewidget.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commita13e26c2f1eb3c5be81acf4f571dd4bafac10199 (patch)
tree1f1d3e407ae668b1448847970b2f1b626083faf6 /kjumpingcube/kcubewidget.cpp
parent24c5cdc2737fe0044b11a12359606973eb93fc0b (diff)
downloadtdegames-a13e26c2f1eb3c5be81acf4f571dd4bafac10199.tar.gz
tdegames-a13e26c2f1eb3c5be81acf4f571dd4bafac10199.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdegames@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kjumpingcube/kcubewidget.cpp')
-rw-r--r--kjumpingcube/kcubewidget.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kjumpingcube/kcubewidget.cpp b/kjumpingcube/kcubewidget.cpp
index d4556eac..9757da99 100644
--- a/kjumpingcube/kcubewidget.cpp
+++ b/kjumpingcube/kcubewidget.cpp
@@ -73,9 +73,9 @@ TQPalette KCubeWidget::color(Owner forWhom)
** public functions **
** ****************************************************** */
-KCubeWidget::KCubeWidget(TQWidget* tqparent,const char* name
+KCubeWidget::KCubeWidget(TQWidget* parent,const char* name
,Owner owner,int value,int max)
- : TQFrame(tqparent,name),
+ : TQFrame(parent,name),
Cube(owner,value,max)
{
setFrameStyle(Panel|Raised);
@@ -85,7 +85,7 @@ KCubeWidget::KCubeWidget(TQWidget* tqparent,const char* name
setCoordinates(0,0);
//initialize hintTimer
// will be automatically destroyed by the tqparent
hintTimer = new TQTimer(this);
hintCounter=0;
connect(hintTimer,TQT_SIGNAL(timeout()),TQT_SLOT(hint()));
@@ -85,7 +85,7 @@ KCubeWidget::KCubeWidget(TQWidget* tqparent,const char* name
setCoordinates(0,0);
//initialize hintTimer
- // will be automatically destroyed by the tqparent
+ // will be automatically destroyed by the parent
hintTimer = new TQTimer(this);
hintCounter=0;